@@ -29,13 +29,14 @@ from .cache import (
     enable_indicator_cache,
     enable_model_cache,
 )
-from .common import BarData, DataCol, Day, PriceType
+from .common import BarData, DataCol, Day, FeeMode, PriceType
 from .context import ExecContext
 from .config import StrategyConfig
 from .data import Alpaca, YFinance
 from .eval import EvalMetrics, BootstrapResult
 from .indicator import Indicator, indicator
 from .model import ModelLoader, ModelSource, ModelTrainer, model
+from .portfolio import Entry, Order, Position, Trade
 from .scope import (
     disable_logging,
     enable_logging,
