@@ -89,8 +89,8 @@ def bca_boot_conf(
             bootstrap sampling.
         n: Number of elements in each random bootstrap sample.
         n_boot: Number of random bootstrap samples to use.
-        fn: ``Callable`` for computing the parameter used for the confidence
-            intervals.
+        fn: :class:`Callable` for computing the parameter used for the
+            confidence intervals.
 
     Returns:
         :class:`.BootConfIntervals` containing the computed confidence
@@ -458,7 +458,7 @@ def upi(
 
 
 def win_loss_rate(pnls: NDArray[np.float_]) -> tuple[float, float]:
-    """Computes the win rate and loss rate.
+    """Computes the win rate and loss rate as percentages.
 
     Args:
         pnls: Array of profits and losses (PnLs) per trade.
@@ -470,11 +470,26 @@ def win_loss_rate(pnls: NDArray[np.float_]) -> tuple[float, float]:
     n = len(pnls)
     if not n:
         return 0, 0
-    win_rate = len(pnls[pnls > 0]) / n
-    loss_rate = len(pnls[pnls < 0]) / n
+    win_rate = len(pnls[pnls > 0]) / n * 100
+    loss_rate = len(pnls[pnls < 0]) / n * 100
     return win_rate, loss_rate
 
 
+def winning_losing_trades(pnls: NDArray[np.float_]) -> tuple[int, int]:
+    """Returns the number of winning and losing trades.
+
+    Args:
+        pnls: Array of profits and losses (PnLs) per trade.
+
+    Returns:
+        ``tuple[int, int]`` containing numbers of winning and losing trades.
+    """
+    pnls = pnls[pnls != 0]
+    if not len(pnls):
+        return 0, 0
+    return len(pnls[pnls > 0]), len(pnls[pnls < 0])
+
+
 def total_profit_loss(pnls: NDArray[np.float_]) -> tuple[float, float]:
     """Computes total profit and loss.
 
@@ -599,10 +614,14 @@ class EvalMetrics:
         total_return_pct: Total realized return measured in percentage.
         total_profit: Total realized profit.
         total_loss: Total realized loss.
+        total_fees: Total brokerage fees. See
+            :attr:`pybroker.config.StrategyConfig.fee_mode` for more info.
         max_drawdown: Maximum drawdown, measured in cash.
         max_drawdown_pct: Maximum drawdown, measured in percentage.
         win_rate: Win rate of trades.
         loss_rate: Loss rate of trades.
+        winning_trades: Number of winning trades.
+        losing_trades: Number of losing trades.
         avg_pnl: Average profit and loss (PnL) per trade, measured in cash.
         avg_return_pct: Average return per trade, measured in percentage.
         avg_trade_bars: Average number of bars per trade.
@@ -636,10 +655,13 @@ class EvalMetrics:
     total_return_pct: float = field(default=0)
     total_profit: float = field(default=0)
     total_loss: float = field(default=0)
+    total_fees: float = field(default=0)
     max_drawdown: float = field(default=0)
     max_drawdown_pct: float = field(default=0)
     win_rate: float = field(default=0)
     loss_rate: float = field(default=0)
+    winning_trades: int = field(default=0)
+    losing_trades: int = field(default=0)
     avg_pnl: float = field(default=0)
     avg_return_pct: float = field(default=0)
     avg_trade_bars: float = field(default=0)
@@ -716,6 +738,7 @@ class EvaluateMixin:
             :class:`.EvalResult` containing evaluation metrics.
         """
         market_values = portfolio_df["market_value"].to_numpy()
+        fees = portfolio_df["fees"].to_numpy()
         bar_returns = self._calc_bar_returns(portfolio_df)
         bar_changes = self._calc_bar_changes(portfolio_df)
         if (
@@ -748,6 +771,7 @@ class EvaluateMixin:
             losing_bars=losing_bars,
             largest_win_num_bars=largest_win_bars,
             largest_loss_num_bars=largest_loss_bars,
+            fees=fees,
         )
         logger = StaticScope.instance().logger
         if not calc_bootstrap:
@@ -793,7 +817,9 @@ class EvaluateMixin:
         losing_bars: NDArray[np.int_],
         largest_win_num_bars: int,
         largest_loss_num_bars: int,
+        fees: NDArray[np.float_],
     ) -> EvalMetrics:
+        total_fees = fees[-1] if len(fees) else 0
         max_dd = max_drawdown(bar_changes)
         max_dd_pct = max_drawdown_percent(bar_returns)
         sharpe = sharpe_ratio(bar_changes)
@@ -806,6 +832,8 @@ class EvaluateMixin:
         largest_loss = 0.0
         win_rate = 0.0
         loss_rate = 0.0
+        winning_trades = 0
+        losing_trades = 0
         avg_pnl = 0.0
         avg_return_pct = 0.0
         avg_trade_bars = 0.0
@@ -823,6 +851,7 @@ class EvaluateMixin:
         if len(pnls):
             largest_win, largest_loss = largest_win_loss(pnls)
             win_rate, loss_rate = win_loss_rate(pnls)
+            winning_trades, losing_trades = winning_losing_trades(pnls)
             avg_profit, avg_loss = avg_profit_loss(pnls)
             avg_profit_pct, avg_loss_pct = avg_profit_loss(return_pcts)
             total_profit, total_loss = total_profit_loss(pnls)
@@ -839,6 +868,9 @@ class EvaluateMixin:
                 avg_winning_trade_bars = float(np.mean(winning_bars))
             if len(losing_bars):
                 avg_losing_trade_bars = float(np.mean(losing_bars))
+        total_return_pct = (
+            (total_pnl + market_values[0]) / market_values[0] - 1
+        ) * 100
         return EvalMetrics(
             trade_count=len(pnls),
             initial_market_value=market_values[0],
@@ -853,6 +885,8 @@ class EvaluateMixin:
             max_losses=max_losses,
             win_rate=win_rate,
             loss_rate=loss_rate,
+            winning_trades=winning_trades,
+            losing_trades=losing_trades,
             avg_pnl=avg_pnl,
             avg_return_pct=avg_return_pct,
             avg_trade_bars=avg_trade_bars,
@@ -865,10 +899,8 @@ class EvaluateMixin:
             total_profit=total_profit,
             total_loss=total_loss,
             total_pnl=total_pnl,
-            total_return_pct=(
-                (total_pnl + market_values[0]) / market_values[0] - 1
-            )
-            * 100,
+            total_return_pct=total_return_pct,
+            total_fees=total_fees,
             sharpe=sharpe,
             profit_factor=pf,
             equity_r2=r2,
