@@ -17,7 +17,7 @@ You should have received a copy of the GNU Lesser General Public License along
 with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-from .common import DataCol, to_decimal
+from .common import DataCol, FeeMode, to_decimal
 from .scope import StaticScope
 from collections import deque
 from dataclasses import dataclass, field
@@ -114,21 +114,23 @@ class Order(NamedTuple):
 
     Attributes:
         id: Unique identifier.
-        date: Date the order was filled.
-        symbol: Ticker symbol of the order.
         type: Type of order, either ``buy`` or ``sell``.
+        symbol: Ticker symbol of the order.
+        date: Date the order was filled.
+        shares: Number of shares bought or sold.
         limit_price: Limit price that was used for the order.
         fill_price: Price that the order was filled at.
-        shares: Number of shares bought or sold.
+        fees: Brokerage fees for order.
     """
 
     id: int
-    date: np.datetime64
-    symbol: str
     type: Literal["buy", "sell"]
+    symbol: str
+    date: np.datetime64
+    shares: int
     limit_price: Optional[Decimal]
     fill_price: Decimal
-    shares: int
+    fees: Decimal
 
 
 class PortfolioBar(NamedTuple):
@@ -143,6 +145,7 @@ class PortfolioBar(NamedTuple):
         pnl: Realized profit and loss (PnL) of :class:`.Portfolio`.
         unrealized_pnl: Unrealized profit and loss (PnL) of
             :class:`.Portfolio`.
+        fees: Brokerage fees.
     """
 
     date: np.datetime64
@@ -152,6 +155,7 @@ class PortfolioBar(NamedTuple):
     market_value: Decimal
     pnl: Decimal
     unrealized_pnl: Decimal
+    fees: Decimal
 
 
 class PositionBar(NamedTuple):
@@ -209,6 +213,8 @@ class Portfolio:
 
     Args:
         cash: Starting cash balance.
+        fee_mode: Brokerage fee mode.
+        fee_amount: Brokerage fee amount.
         max_long_positions: Maximum number of long :class:`.Position`\ s that
             can be held at a time. If ``None``, then unlimited.
         max_short_positions: Maximum number of short :class:`.Position`\ s that
@@ -220,6 +226,7 @@ class Portfolio:
         market_value: Current market value. The market value is defined as
             the amount of equity held in cash and long positions added together
             with the unrealized PnL of all open short positions.
+        fees: Current brokerage fees.
         orders: ``deque`` of all filled orders, sorted in ascending
             chronological order.
         margin: Current amount of margin held in open positions.
@@ -242,12 +249,19 @@ class Portfolio:
     def __init__(
         self,
         cash: float,
+        fee_mode: Optional[FeeMode] = None,
+        fee_amount: Optional[float] = None,
         max_long_positions: Optional[int] = None,
         max_short_positions: Optional[int] = None,
     ):
         self.cash: Decimal = to_decimal(cash)
+        self._fee_mode = fee_mode
+        self._fee_amount: Optional[Decimal] = (
+            None if fee_amount is None else to_decimal(fee_amount)
+        )
         self.equity: Decimal = self.cash
         self.market_value: Decimal = self.cash
+        self.fees = Decimal()
         self._max_long_positions = max_long_positions
         self._max_short_positions = max_short_positions
         self.orders: deque[Order] = deque()
@@ -261,6 +275,20 @@ class Portfolio:
         self.position_bars: deque[PositionBar] = deque()
         self._logger = StaticScope.instance().logger
 
+    def _calculate_fees(self, fill_price: Decimal, shares: int) -> Decimal:
+        fees = Decimal()
+        if self._fee_mode is None or self._fee_amount is None:
+            return fees
+        if self._fee_mode == FeeMode.ORDER_PERCENT:
+            fees = self._fee_amount * fill_price * shares
+        elif self._fee_mode == FeeMode.PER_ORDER:
+            fees = self._fee_amount
+        elif self._fee_mode == FeeMode.PER_SHARE:
+            fees = self._fee_amount * shares
+        else:
+            raise ValueError(f"Unknown FeeMode: {self._fee_mode!r}")
+        return fees
+
     def _verify_input(
         self,
         shares: int,
@@ -274,6 +302,27 @@ class Portfolio:
         if limit_price is not None and limit_price <= 0:
             raise ValueError(f"Limit price must be > 0: {limit_price}")
 
+    def _add_entry(
+        self,
+        date: np.datetime64,
+        symbol: str,
+        shares: int,
+        price: Decimal,
+        type: Literal["long", "short"],
+        pos: Position,
+    ) -> Entry:
+        self._entry_id += 1
+        entry = Entry(
+            id=self._entry_id,
+            symbol=symbol,
+            shares=shares,
+            price=price,
+            date=date,
+            type=type,
+        )
+        pos.entries.append(entry)
+        return entry
+
     def _add_order(
         self,
         date: np.datetime64,
@@ -284,6 +333,7 @@ class Portfolio:
         shares: int,
     ) -> Order:
         self._order_id += 1
+        fees = self._calculate_fees(fill_price, shares)
         order = Order(
             id=self._order_id,
             date=date,
@@ -292,8 +342,10 @@ class Portfolio:
             limit_price=limit_price,
             fill_price=fill_price,
             shares=shares,
+            fees=fees,
         )
         self.orders.append(order)
+        self.fees += fees
         return order
 
     def _add_trade(
@@ -388,6 +440,7 @@ class Portfolio:
         pos = self.short_positions[symbol]
         while pos.entries:
             entry = pos.entries[0]
+            return_pct = ((entry.price / fill_price) - 1) * 100
             if rem_shares >= entry.shares:
                 order_amount = entry.shares * fill_price
                 entry_amount = entry.shares * entry.price
@@ -407,7 +460,7 @@ class Portfolio:
                     exit_date=date,
                     shares=entry.shares,
                     pnl=entry_pnl,
-                    return_pct=((entry.price / fill_price) - 1) * 100,
+                    return_pct=return_pct,
                     cumulative_pnl=self.pnl + pnl,
                     bars=entry.bars,
                     pnl_per_bar=pnl_per_bar,
@@ -429,7 +482,7 @@ class Portfolio:
                     exit_date=date,
                     shares=rem_shares,
                     pnl=entry_pnl,
-                    return_pct=((entry.price / fill_price) - 1) * 100,
+                    return_pct=return_pct,
                     cumulative_pnl=self.pnl + pnl,
                     bars=entry.bars,
                     pnl_per_bar=pnl_per_bar,
@@ -461,15 +514,6 @@ class Portfolio:
             return 0
         order_amount = shares * fill_price
         self.cash -= order_amount
-        self._entry_id += 1
-        entry = Entry(
-            id=self._entry_id,
-            symbol=symbol,
-            shares=shares,
-            price=fill_price,
-            date=date,
-            type="long",
-        )
         if symbol not in self.long_positions:
             self.symbols.add(symbol)
             pos = Position(symbol=symbol, shares=shares, type="long")
@@ -477,7 +521,14 @@ class Portfolio:
         else:
             pos = self.long_positions[symbol]
             pos.shares += shares
-        pos.entries.append(entry)
+        self._add_entry(
+            date=date,
+            symbol=symbol,
+            shares=shares,
+            price=fill_price,
+            type="long",
+            pos=pos,
+        )
         return shares
 
     def sell(
@@ -541,6 +592,7 @@ class Portfolio:
         pos = self.long_positions[symbol]
         while pos.entries:
             entry = pos.entries[0]
+            return_pct = ((fill_price / entry.price) - 1) * 100
             if rem_shares >= entry.shares:
                 order_amount = entry.shares * fill_price
                 entry_amount = entry.shares * entry.price
@@ -560,7 +612,7 @@ class Portfolio:
                     exit_date=date,
                     shares=entry.shares,
                     pnl=entry_pnl,
-                    return_pct=((fill_price / entry.price) - 1) * 100,
+                    return_pct=return_pct,
                     cumulative_pnl=self.pnl + pnl,
                     bars=entry.bars,
                     pnl_per_bar=pnl_per_bar,
@@ -582,7 +634,7 @@ class Portfolio:
                     exit_date=date,
                     shares=rem_shares,
                     pnl=entry_pnl,
-                    return_pct=((fill_price / entry.price) - 1) * 100,
+                    return_pct=return_pct,
                     cumulative_pnl=self.pnl + pnl,
                     bars=entry.bars,
                     pnl_per_bar=pnl_per_bar,
@@ -612,15 +664,6 @@ class Portfolio:
         ):
             return 0
         self.cash += shares * fill_price
-        self._entry_id += 1
-        entry = Entry(
-            id=self._entry_id,
-            symbol=symbol,
-            shares=shares,
-            price=fill_price,
-            date=date,
-            type="short",
-        )
         if symbol not in self.short_positions:
             self.symbols.add(symbol)
             pos = Position(symbol=symbol, shares=shares, type="short")
@@ -628,7 +671,14 @@ class Portfolio:
         else:
             pos = self.short_positions[symbol]
             pos.shares += shares
-        pos.entries.append(entry)
+        self._add_entry(
+            date=date,
+            symbol=symbol,
+            shares=shares,
+            price=fill_price,
+            type="short",
+            pos=pos,
+        )
         return shares
 
     def capture_bar(self, date: np.datetime64, df: pd.DataFrame):
@@ -704,6 +754,7 @@ class Portfolio:
                 margin=self.margin,
                 pnl=self.pnl,
                 unrealized_pnl=total_pnl,
+                fees=self.fees,
             )
         )
 
